**Example 1: 删除规则示例**



Input: 

```
tccli iotcloud DeleteTopicRule --cli-unfold-argument  \
    --RuleName test
```

Output: 
```
{
    "Response": {
        "RequestId": "be69a7a3-7315-40a7-9532-3316e4a3e97e"
    }
}
```

